import json

import django_rq

from django.core.mail import EmailMessage

from councilmatic_core.models import Bill, Events

from notifications.models import PersonSubscription, \
    CommitteeActionSubscription, 


def handle_bill_search_subscriptions(user, update_since, created_bills_ids, updated_bills_ids, created_events_ids, updated_events_ids):
    billsearch_subscriptions = BillSearchSubscription.objects.filter(user=user)
    person_updates = [] # list of bills sponsored by a person since subscriptions' last_datetime_updated
    committee_action_updates = [] # list of actions taken by a committee since subscriptions' last_datetime_updated
    committee_event_updates = [] # list of events taken by a committee since subscriptions' last_datetime_updated
    bill_search_updates = [] # list of new bills now showing up on a search since subscriptions' last_datetime_updated
    bill_action_updates = [] # list of actions taken on a bill since subscriptions' last_datetime_updated
    events_updates = [] # list of events since subscriptions' last_datetime_updated
    # XXX It's unclear how to proceed here but perhaps evz can weigh in on what the search actually searches,
    # XXX and whether we can simulate that in Python or whether it makes more sense to interact directly with
    # XXX the solr interface on the imported stuff.
    # XXX
    # XXX However, the problem is that with the current cron system, the indexes are not updated immediately
    # XXX with the new data.
    print ("NOT doing bill search subscriptions")

    return bill_search_updates

def handle_events_subscriptions(user, update_since, created_bills_ids, updated_bills_ids, created_events_ids, updated_events_ids):
    event_updates = []
    events_subscriptions = EventsSubscription.objects.filter(user=user)

    # Basically just return all new events if this is what we are subscribed
    # to.  XXX: Whether we include or differentiate updated events will depend
    # on how often updated events actually occur in practice with daily
    # updates.
    all_events_ids = created_events_ids + updated_events_ids
    events = Event.objects.filter(
        Q(id__in=all_events_ids)).order_by('-start_time')
    for event in events:
        event_updates.append(event) #XXX for now, conflate created and updated events
    return event_updates




# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-09-14 16:01
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('notifications', '0002_auto_20160527_1624'),
    ]

    operations = [
        migrations.CreateModel(
            name='EventsSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_datetime_updated', models.DateTimeField(auto_now=True)),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='eventssubscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterField(
            model_name='billactionsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='billactionsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billsearchsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='billsearchsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='committeeactionsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='committeeactionsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='committeeeventsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='committeeeventsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='personsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='personsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-23 20:12
from __future__ import unicode_literals

from django.conf import settings
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('councilmatic_core', '0010_auto_20160120_1248'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='BillActionSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('bill', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subscriptions', to='councilmatic_core.Bill')),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='billactionsubscription_subscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BillSearchSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('search_term', models.CharField(max_length=256)),
                ('search_facets', django.contrib.postgres.fields.jsonb.JSONField()),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='billsearchsubscription_subscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommitteeActionSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('committee', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subscriptions_actions', to='councilmatic_core.Organization')),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='committeeactionsubscription_subscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommitteeEventSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('committee', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subscriptions_events', to='councilmatic_core.Organization')),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='committeeeventsubscription_subscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PersonSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('person', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subscriptions', to='councilmatic_core.Person')),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='personsubscription_subscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
